""" Wlogger : Release file """

name = 'wlogger'
major = '0'
minor = '1'
maintenance = '1'

__version__ = major + '.' + minor + '.' + maintenance

__date__ = '2015-12-22' 

__description__ = 'Minimalistic command-line progress tracker.'

__author__ = 'Kumar Krishna Agrawal'
__email__ = 'kumarkrishna.iitkgp@gmail.com'
